package internal

import (
	"context"
	"encoding/json"
	"fmt"
	"gitea.cdlsxd.cn/sdk/plugin/proto"
	"github.com/stretchr/testify/assert"
	"testing"
)

var zltx = &ZLTXV1Service{}

func config() []byte {
	c := &Config{
		AppId:      "1",
		AppKey:     "1e2bf7a04b8b1e6be5dc78d04e8639c9",
		BaseUri:    "http://test.openapi.1688sup.cn",
		NotifyUrl:  "https://gateway.dev.cdlsxd.cn/yxh5api/v1/order/direct/notify",
		MerchantId: "25537",
	}
	marshal, _ := json.Marshal(c)
	return marshal
}

func TestConfig(t *testing.T) {
	t.Run("TestConfig", func(t *testing.T) {
		c := config()
		fmt.Printf("%s\n", string(c))
		assert.NotEmpty(t, c)
	})
}

func TestOrder(t *testing.T) {
	request := &proto.OrderRequest{
		Config: config(),
		Order: &proto.OrderRequest_Order{
			OrderNo:  "test_zltx_v1_direct_2",
			Account:  "18666666666",
			Quantity: 1,
			Extra:    nil,
		},
		Product: &proto.OrderRequest_Product{
			ProductNo: "101",
			Extra:     []byte(`{}`),
		},
	}

	t.Run("TestOrder", func(t *testing.T) {
		got, err := zltx.Order(context.Background(), request)
		if err != nil {
			t.Errorf("Order() error = %v", err)
			return
		}
		t.Logf("%+v\n", got)
		assert.Equal(t, int(proto.Status_ING), int(got.Result.Status))
	})
}

func TestQuery(t *testing.T) {
	request := &proto.QueryRequest{
		Config: config(),
		Order: &proto.QueryRequest_Order{
			OrderNo: "test_zltx_v1_direct_1",
			TradeNo: "",
			Account: "",
			Extra:   nil,
		},
	}
	t.Run("TestQuery", func(t *testing.T) {
		got, err := zltx.Query(context.Background(), request)
		if err != nil {
			t.Errorf("Query() error = %v", err)
			return
		}
		t.Logf("%+v\n", got)
		assert.Equal(t, int(proto.Status_SUCCESS), int(got.Result.Status))
	})
}

func TestNotify(t *testing.T) {
	in := &proto.NotifyRequest{
		Config:  config(),
		Queries: nil,
		Headers: []byte(`{"Content-Type":["application/json"],"Authorization":["MD5 appid=101,sign=292e21f3683219369cf68dede0d45730"]`),
		Body:    []byte(`{"merchantId":23329,"outTradeNo":"202409111714224026320002","rechargeAccount":"18512869479","sign":"474ACB521DEE99551153B6CE108FD06D","status":"01"}`),
	}
	t.Run("TestNotify", func(t *testing.T) {
		got, err := zltx.Notify(context.Background(), in)
		if !assert.Nil(t, err) {
			t.Errorf("Notify() error = %v", err)
			return
		}
		fmt.Printf("%s \n", got.String())
		assert.Equal(t, int(proto.Status_SUCCESS), int(got.Result.Status))
	})
}
